@@ -2,6 +2,7 @@ use ckb_chain_spec::consensus::TWO_IN_TWO_OUT_CYCLES;
 use ckb_jsonrpc_types::FeeRateDef;
 use ckb_types::core::{Cycle, FeeRate};
 use serde::Deserialize;
+use std::cmp;
 use std::path::PathBuf;
 
 // default min fee rate, 1000 shannons per kilobyte
@@ -9,7 +10,9 @@ const DEFAULT_MIN_FEE_RATE: FeeRate = FeeRate::from_u64(1000);
 // default max tx verify cycles
 const DEFAULT_MAX_TX_VERIFY_CYCLES: Cycle = TWO_IN_TWO_OUT_CYCLES * 20;
 // default max ancestors count
-const DEFAULT_MAX_ANCESTORS_COUNT: usize = 25;
+const DEFAULT_MAX_ANCESTORS_COUNT: usize = 125;
+// Default expiration time for pool transactions in hours
+const DEFAULT_EXPIRY_HOURS: u8 = 24;
 
 #[derive(Clone, Debug, Deserialize)]
 #[serde(deny_unknown_fields)]
@@ -31,6 +34,8 @@ pub(crate) struct TxPoolConfig {
     persisted_data: PathBuf,
     #[serde(default)]
     recent_reject: PathBuf,
+    #[serde(default = "default_expiry_hours")]
+    expiry_hours: u8,
 }
 
 fn default_keep_rejected_tx_hashes_days() -> u8 {
@@ -41,6 +46,10 @@ fn default_keep_rejected_tx_hashes_count() -> u64 {
     10_000_000
 }
 
+fn default_expiry_hours() -> u8 {
+    DEFAULT_EXPIRY_HOURS
+}
+
 impl Default for crate::TxPoolConfig {
     fn default() -> Self {
         TxPoolConfig::default().into()
@@ -62,6 +71,7 @@ impl Default for TxPoolConfig {
             max_ancestors_count: DEFAULT_MAX_ANCESTORS_COUNT,
             persisted_data: Default::default(),
             recent_reject: Default::default(),
+            expiry_hours: DEFAULT_EXPIRY_HOURS,
         }
     }
 }
@@ -81,17 +91,19 @@ impl From<TxPoolConfig> for crate::TxPoolConfig {
             max_ancestors_count,
             persisted_data,
             recent_reject,
+            expiry_hours,
         } = input;
         Self {
             max_mem_size,
             max_cycles,
             min_fee_rate,
             max_tx_verify_cycles,
-            max_ancestors_count,
+            max_ancestors_count: cmp::max(DEFAULT_MAX_ANCESTORS_COUNT, max_ancestors_count),
             keep_rejected_tx_hashes_days,
             keep_rejected_tx_hashes_count,
             persisted_data,
             recent_reject,
+            expiry_hours,
         }
     }
 }
